@@ -28,6 +28,7 @@
 #include <QToolTip>
 #include <QAction>
 
+#include <kcoreaddons_version.h>
 #include <KLocalizedString>
 #include <KMessageBox>
 
@@ -37,8 +38,6 @@ AltTransView::AltTransView(QWidget* parent, Catalog* catalog, const QVector<QAct
     , m_catalog(catalog)
     , m_normTitle(i18nc("@title:window", "Alternate Translations"))
     , m_hasInfoTitle(m_normTitle + QStringLiteral(" [*]"))
-    , m_hasInfo(false)
-    , m_everShown(false)
     , m_actions(actions)
 {
     setObjectName(QStringLiteral("msgIdDiff"));
@@ -98,7 +97,7 @@ void AltTransView::attachAltTransFile(const QString& path)
 void AltTransView::addAlternateTranslation(int entry, const QString& trans)
 {
     AltTrans altTrans;
-    altTrans.target = trans;
+    altTrans.target = CatalogString(trans);
     m_catalog->attachAltTrans(entry, altTrans);
 
     m_prevEntry = DocPos();
@@ -111,11 +110,11 @@ void AltTransView::fileLoaded()
     QString absPath = m_catalog->url();
     QString relPath = QDir(Project::instance()->poDir()).relativeFilePath(absPath);
 
-    QFileInfo info(Project::instance()->altTransDir() % '/' % relPath);
+    QFileInfo info(Project::instance()->altTransDir() + QLatin1Char('/') + relPath);
     if (info.canonicalFilePath() != absPath && info.exists())
         attachAltTransFile(info.canonicalFilePath());
     else
-        qCWarning(LOKALIZE_LOG) << "alt trans file doesn't exist:" << Project::instance()->altTransDir() % '/' % relPath;
+        qCWarning(LOKALIZE_LOG) << "alt trans file doesn't exist:" << Project::instance()->altTransDir() + QLatin1Char('/') + relPath;
 }
 
 void AltTransView::slotNewEntryDisplayed(const DocPosition& pos)
@@ -149,18 +148,31 @@ void AltTransView::process()
         setWindowTitle(m_hasInfoTitle);
     }
     if (!isVisible() && !Settings::altTransViewEverShownWithData()) {
+#if KCOREADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (KMessageBox::PrimaryAction == KMessageBox::questionTwoActions(
+                    this,
+                    i18n("There is useful data available in Alternate Translations view.\n\n"
+                         "For Gettext PO files it displays difference between current source text "
+                         "and the source text corresponding to the fuzzy translation found by msgmerge when updating PO based on POT template.\n\n"
+                         "Do you want to show the view with the data?"),
+                    i18nc("@title", "Alternative Translations Available"),
+                    KGuiItem(i18nc("@action", "Show Data View")),
+                    KStandardGuiItem::cancel())) {
+#else
         if (KMessageBox::questionYesNo(this, i18n("There is useful data available in Alternate Translations view.\n\n"
                                        "For Gettext PO files it displays difference between current source text "
                                        "and the source text corresponding to the fuzzy translation found by msgmerge when updating PO based on POT template.\n\n"
-                                       "Do you want to show the view with the data?"), m_normTitle) == KMessageBox::Yes)
+                                       "Do you want to show the view with the data?"), m_normTitle) == KMessageBox::Yes) {
+#endif
             show();
+        }
 
         Settings::setAltTransViewEverShownWithData(true);
     }
 
     CatalogString source = m_catalog->sourceWithTags(m_entry.toDocPosition());
     QString context = m_catalog->context(m_entry.toDocPosition()).first();
-    QString contextWithNewline = context + (context.isEmpty() ? "" : "\n");
+    QString contextWithNewline = context + (context.isEmpty() ? QString() : QStringLiteral("\n"));
 
     QTextBlockFormat blockFormatBase;
     QTextBlockFormat blockFormatAlternate; blockFormatAlternate.setBackground(QPalette().alternateBase());
@@ -301,4 +313,4 @@ void AltTransView::slotUseSuggestion(int i)
     Q_EMIT refreshRequested();
 }
 
-
+#include "moc_alttransview.cpp"
